@@ -15,15 +15,13 @@
 
 import os
 import string
-import logging
-logger = logging.getLogger('Zope Security Policy')
+from logging import getLogger
 
 from Acquisition import aq_base
 from Acquisition import aq_parent
 from Acquisition import aq_inner
 from Acquisition import aq_acquire
 from ExtensionClass import Base
-from zLOG.EventLogger import CUSTOM_BLATHER
 from zope.interface import implements
 
 # This is used when a permission maps explicitly to no permission.  We
@@ -41,6 +39,7 @@ from AccessControl.interfaces import ISecurityManager
 from AccessControl.SimpleObjectPolicies import Containers, _noroles
 from AccessControl.ZopeGuards import guarded_getitem
 
+LOG = getLogger('ImplPython')
 
 # AccessControl.PermissionRole
 # ----------------------------
@@ -318,9 +317,8 @@ class ZopeSecurityPolicy:
                             None)
 
             if p is not None:
-                tp = p.__class__
-                if tp is not int and tp is not bool:
-                    if tp is dict:
+                if not isinstance(p, int): # catches bool too
+                    if isinstance(p, dict):
                         if isinstance(name, basestring):
                             p = p.get(name)
                         else:
@@ -348,8 +346,8 @@ class ZopeSecurityPolicy:
                 return 1
         except TypeError:
             # 'roles' isn't a sequence
-            logger.warn("'%s' passed as roles"
-                        " during validation of '%s' is not a sequence." % (
+            LOG.error("'%s' passed as roles"
+                " during validation of '%s' is not a sequence." % (
                 `roles`, name))
             raise
 
@@ -806,7 +804,7 @@ def raiseVerbose(msg, accessed, container, name, value, context,
         info.append(s + '.')
 
     text = ' '.join(info)
-    logger.log(CUSTOM_BLATHER, 'Unauthorized: %s' % text)
+    LOG.debug('Unauthorized: %s' % text)
     raise Unauthorized(text)
 
 def getUserRolesInContext(user, context):
