@@ -1,9 +1,5 @@
 import unittest
 
-import Testing
-import Zope2
-Zope2.startup()
-
 from OFS.CopySupport import CopySource
 from OFS.ObjectManager import ObjectManager
 
@@ -18,6 +14,8 @@ class DummyObject(CopySource):
         return
     def manage_beforeDelete(self, item, container):
         return
+    manage_afterAdd.__five_method__ = True
+    manage_beforeDelete.__five_method__ = True
     def wl_isLocked(self):
         return 0
 
@@ -44,6 +42,20 @@ class TestOrderSupport(unittest.TestCase):
         f.o4 = DummyObject('o4', 'mt2')
         return f
 
+    def test_z2interfaces(self):
+        from Interface.Verify import verifyClass
+        from OFS.IOrderSupport import IOrderedContainer
+        from OFS.OrderSupport import OrderSupport
+
+        verifyClass(IOrderedContainer, OrderSupport)
+
+    def test_z3interfaces(self):
+        from OFS.interfaces import IOrderedContainer
+        from OFS.OrderSupport import OrderSupport
+        from zope.interface.verify import verifyClass
+
+        verifyClass(IOrderedContainer, OrderSupport)
+
     def _doCanonTest(self, methodname, table):
         for args, order, rval in table:
             f = self._makeOne()
@@ -160,13 +172,6 @@ class TestOrderSupport(unittest.TestCase):
         f.setDefaultSorting('position', True)
         self.failUnlessEqual( f.tpValues(), [f.o4, f.o3, f.o2] )
 
-    def test_z2interfaces(self):
-        from Interface.Verify import verifyClass
-        from OFS.IOrderSupport import IOrderedContainer
-        from OFS.OrderSupport import OrderSupport
-
-        verifyClass(IOrderedContainer, OrderSupport)
-
 
 def test_suite():
     return unittest.TestSuite((
