@@ -16,9 +16,10 @@
 Directives to emulate the 'http://namespaces.zope.org/browser'
 namespace in ZCML known from zope.app.
 
-$Id: metaconfigure.py 68289 2006-05-25 20:44:07Z rocky $
+$Id: metaconfigure.py 71459 2006-12-06 17:50:26Z alecm $
 """
 import os
+from inspect import ismethod
 
 from zope import component
 from zope.interface import Interface
@@ -41,6 +42,7 @@ from Products.Five.browser.resource import DirectoryResourceFactory
 from Products.Five.browser.pagetemplatefile import ZopeTwoPageTemplateFile
 from Products.Five.metaclass import makeClass
 from Products.Five.security import getSecurityInfo, protectClass, protectName
+from Products.Five.security import CheckerPrivateId
 
 from Globals import InitializeClass as initializeClass
 
@@ -138,6 +140,19 @@ def page(_context, name, permission, for_,
                 callable = protectName,
                 args = (new_class, attr, permission)
                 )
+    # Make everything else private
+    allowed = [attribute] + (allowed_attributes or [])
+    private_attrs = [name for name in dir(new_class)
+                     if (not name.startswith('_')) and
+                        (name not in allowed) and
+                        ismethod(getattr(new_class, name))]
+    for attr in private_attrs:
+        _context.action(
+            discriminator = ('five:protectName', new_class, attr),
+            callable = protectName,
+            args = (new_class, attr, CheckerPrivateId)
+            )
+    # Protect the class
     _context.action(
         discriminator = ('five:initialize:class', new_class),
         callable = initializeClass,
@@ -386,10 +401,7 @@ class ViewMixinForAttributes(BrowserView):
     # this is technically not needed because ZPublisher finds our
     # attribute through __browser_default__; but we also want to be
     # able to call pages from python modules, PythonScripts or ZPT
-    def __call__(self, *args, **kw):
-        attr = self.__page_attribute__
-        meth = getattr(self, attr)
-        return meth(*args, **kw)
+    __call__ = property(lambda self: getattr(self, self.__page_attribute__))
 
 class ViewMixinForTemplates(BrowserView):
 
