@@ -34,6 +34,7 @@ from AccessControl import getSecurityManager
 from OFS.History import Historical, html_diff
 from OFS.Cache import Cacheable
 from AccessControl.ZopeGuards import get_safe_globals, guarded_getattr
+from AccessControl.requestmethod import postonly
 
 from zExceptions import Forbidden
 import Globals
@@ -360,6 +361,7 @@ class PythonScript(Script, Historical, Cacheable):
       'manage_proxyForm', 'manage_proxy')
 
     manage_proxyForm = DTMLFile('www/pyScriptProxy', globals())
+    @postonly
     def manage_proxy(self, roles=(), REQUEST=None):
         "Change Proxy Roles"
         self._validateProxy(roles)
@@ -417,7 +419,7 @@ class PythonScript(Script, Historical, Cacheable):
                 k = k.strip().lower()
                 v = v.strip()
                 if not mdata.has_key(k):
-                    SyntaxError, 'Unrecognized header line "%s"' % line
+                    raise SyntaxError, 'Unrecognized header line "%s"' % line
                 if v == mdata[k]:
                     # Unchanged value
                     continue
