@@ -128,9 +128,6 @@ class TestPythonScriptNoAq(PythonScriptTestBase):
         res = self._newPS('return 1 * 5 + 4 / 2 - 6')()
         self.assertEqual(res, 1)
 
-    def testCollector2295(self):
-        res = self._newPS('if False:\n  pass\n#hi')
-
     def testReduce(self):
         res = self._newPS('return reduce(lambda x, y: x + y, [1,3,5,7])')()
         self.assertEqual(res, 16)
@@ -229,7 +226,8 @@ class TestPythonScriptErrors(PythonScriptTestBase):
 
     def testBadImports(self):
         self.assertPSRaises(ImportError, body="from string import *")
-        self.assertPSRaises(ImportError, body="import mmap")
+        self.assertPSRaises(ImportError, body="from datetime import datetime")
+        #self.assertPSRaises(ImportError, body="import mmap")
 
     def testAttributeAssignment(self):
         # It's illegal to assign to attributes of anything that
