@@ -12,7 +12,7 @@
 ##############################################################################
 """Support for (functional) doc tests
 
-$Id: functional.py 76991 2007-06-23 17:26:25Z shh $
+$Id: functional.py 73184 2007-03-15 09:58:25Z shh $
 """
 
 import sys, re, base64
@@ -31,6 +31,7 @@ from Testing.ZopeTestCase import user_role
 from Testing.ZopeTestCase import standard_permissions
 from Testing.ZopeTestCase.sandbox import AppZapper
 from Testing.ZopeTestCase.functional import ResponseWrapper
+from Testing.ZopeTestCase.functional import savestate
 
 
 class HTTPHeaderOutput:
@@ -110,6 +111,7 @@ def sync():
     getRootFolder()._p_jar.sync()
 
 
+@savestate
 def http(request_string, handle_errors=True):
     """Execute an HTTP request string via the publisher
 
@@ -120,11 +122,6 @@ def http(request_string, handle_errors=True):
     from cStringIO import StringIO
     from ZPublisher.Response import Response
     from ZPublisher.Test import publish_module
-    from AccessControl.SecurityManagement import getSecurityManager
-    from AccessControl.SecurityManagement import setSecurityManager
-
-    # Save current Security Manager
-    old_sm = getSecurityManager()
 
     # Commit work done by previous python code.
     transaction.commit()
@@ -189,11 +186,6 @@ def http(request_string, handle_errors=True):
     header_output.appendResponseHeaders(response._cookie_list())
     header_output.appendResponseHeaders(response.accumulated_headers.splitlines())
 
-    # Restore previous security manager, which may have been changed
-    # by calling the publish method above
-    setSecurityManager(old_sm)
-
-    # Sync connection
     sync()
 
     return DocResponseWrapper(response, outstream, path, header_output)
@@ -261,7 +253,6 @@ class ZopeSuiteFactory:
             if hasattr(test_instance, 'portal'):
                 test.globs['portal'] = test_instance.portal
                 test.globs['portal_name'] = test_instance.portal.getId()
-            test_instance.globs = test.globs
             if kwsetUp is not None:
                 kwsetUp(test_instance)
 
@@ -300,7 +291,7 @@ class FunctionalSuiteFactory(ZopeSuiteFactory):
             name = test_class.__name__
             warnings.warn(("The test_class you are using doesn't "
                            "subclass from ZopeTestCase.Functional. "
-                           "Please fix that."), UserWarning, 4)
+                           "Please fix that."), UserWarning, 2)
             if not 'Functional' in name:
                 name = 'Functional%s' % name
             test_class = type(name, (Functional, test_class), {})
