@@ -121,6 +121,13 @@ class HTTPResponseTests(unittest.TestCase):
         self.assertEqual(response.body, unicode('rger',
                          'iso-8859-15').encode('utf-8'))
 
+    def test_XMLEncodingRecoding(self):
+        xml = u'<?xml version="1.0" encoding="iso-8859-15" ?>\n<foo><bar/></foo>'
+        response = self._makeOne(body=xml, headers={'content-type': 'text/xml; charset=utf-8'})
+        self.assertEqual(xml.replace('iso-8859-15', 'utf-8')==response.body, True)
+        response = self._makeOne(body=xml, headers={'content-type': 'text/xml; charset=iso-8859-15'})
+        self.assertEqual(xml==response.body, True)
+
 
 def test_suite():
     suite = unittest.TestSuite()
