@@ -13,19 +13,19 @@
 ##############################################################################
 """Unit tests for RAM Cache.
 
-$Id: test_ramcache.py 77124 2007-06-27 12:50:19Z nouri $
+$Id: test_ramcache.py 67630 2006-04-27 00:54:03Z jim $
 """
 from time import time
 from unittest import TestCase, TestSuite, main, makeSuite
 
 from zope.interface.verify import verifyClass, verifyObject
 from zope.interface import implements
+from zope.traversing.interfaces import IPhysicallyLocatable
 
 from zope.app.cache.ram import RAMCache
 from zope.app.cache.tests.test_icache import BaseICacheTest
 from zope.app.cache.interfaces import ICache
 from zope.app.cache.interfaces.ram import IRAMCache
-from zope.app.traversing.interfaces import IPhysicallyLocatable
 from zope.app.testing.placelesssetup import PlacelessSetup
 
 class Locatable(object):
@@ -238,6 +238,21 @@ class TestStorage(TestCase):
             raise "ExpectedKeyError"
         self.assertEqual(s._misses[object2], 1)
 
+    def test_getEntry_do_cleanup(self):
+         from zope.app.cache.ram import Storage
+
+         s = Storage(cleanupInterval=300, maxAge=300)
+         object = 'object'
+         key = ('view', (), ('answer', 42))
+         value = 'yes'
+
+         s.setEntry(object, key, value)
+
+         s._data[object][key][1] = time() - 400
+         s.lastCleanup = time() - 400
+
+         self.assertRaises(KeyError, s.getEntry, object, key)
+
     def test_setEntry(self):
         from zope.app.cache.ram import Storage
 
@@ -434,15 +449,15 @@ class TestStorage(TestCase):
         value = 'yes'
         timestamp = time()
         s._data = {object:  {key1: [value, 1, 10],
-                             key2: [value, 6, 5],
-                             key3: [value, 2, 2]},
-                   object2: {key1: [value, 5, 2],
-                             key2: [value, 3, 1],
-                             key3: [value, 4, 1]}}
+                             key2: [value, 2, 5],
+                             key3: [value, 3, 2]},
+                   object2: {key1: [value, 4, 2],
+                             key2: [value, 5, 1],
+                             key3: [value, 6, 1]}}
         s.removeLeastAccessed()
         self.assertEqual(s._data,
                          {object:  {key1: [value, 1, 0],
-                                    key2: [value, 6, 0]}},
+                                    key2: [value, 2, 0]}},
                          'least records removed incorrectly')
 
         s = Storage(maxEntries=6)
@@ -487,8 +502,8 @@ class TestStorage(TestCase):
         self.assertEqual(s._misses, clearMisses, "misses counter not cleared")
 
     def test_getStatistics(self):
-        from zope.app.cache.ram import Storage
-        from pickle import dumps
+        from zope.app.cache.ram import Storage, dumps
+
         s = Storage(maxEntries=3)
         object = 'object'
         object2 = 'object2'
@@ -523,7 +538,7 @@ class TestStorage(TestCase):
 
         result = s.getStatistics()
 
-        self.assertEqual(result, expected, "got unexpected stats")
+        self.assertEqual(result, expected)
 
 
 class TestModule(TestCase):
