@@ -13,9 +13,10 @@
 ##############################################################################
 """Multi-Checkbox Widget Tests 
 
-$Id: test_multicheckboxwidget.py 26567 2004-07-16 06:58:27Z srichter $
+$Id: test_multicheckboxwidget.py 69217 2006-07-20 03:56:26Z baijum $
 """
-import unittest, doctest
+import unittest
+from zope.testing import doctest
 from zope.interface import Interface, implements
 from zope.publisher.browser import TestRequest
 from zope.schema import Choice, List
