@@ -16,32 +16,12 @@
 These exceptions are so general purpose that they don't belong in Zope
 application-specific packages.
 
-$Id: __init__.py 37531 2005-07-28 14:02:49Z anguenot $
+$Id: __init__.py 67636 2006-04-27 11:31:54Z srichter $
 """
+from zope.exceptions.interfaces import DuplicationError, IDuplicationError
+from zope.exceptions.interfaces import UserError, IUserError
 
-import zope.deprecation
-
-zope.deprecation.deprecated('INotFoundError',
-                            'This interface has been deprecated. '
-                            'Use standard interface instead '
-                            'The reference will be gone in 3.3')
-
-zope.deprecation.deprecated('NotFoundError',
-                            'This class has been deprecated. '
-                            'Use standard exceptions instead '
-                            'The reference will be gone in 3.3')
-
-# Turn of deprecation warning here for the above import that are here for BBB
-# The depreaction above and within the _notfounderror module will do the job.
-zope.deprecation.__show__.off()
-from zope.exceptions._notfounderror import NotFoundError, INotFoundError
-zope.deprecation.__show__.on()
-
-from zope.exceptions._duplicate import DuplicationError, IDuplicationError
-
-# Importing these interfaces from here is deprecated!
-
-# avoid depency on zope.security:
+# avoid dependency on zope.security:
 try:
     import zope.security
 except ImportError, v:
