@@ -11,8 +11,13 @@
 #
 ##############################################################################
 """
-
-$Id: __init__.py 33262 2005-07-10 17:05:28Z jim $
+$Id: __init__.py 67630 2006-04-27 00:54:03Z jim $
 """
 
-from zope.formlib.page import Page
+# BBB 2006/04/19 -- to be removed after 12 months
+import zope.deferredimport
+zope.deferredimport.deprecated(
+    "It has moved to zope.publisher.browser.BrowserPage.  This reference "
+    "will be gone in Zope 3.5.",
+    Page = 'zope.publisher.browser:BrowserPage',
+    )
